@@ -3,7 +3,7 @@
 SRE.fit <- function(object, n_EM = 100L, tol = 0.01, method = c("EM", "TMB"),
                     lambda = 0, print_lik = FALSE, optimiser = nlminb, 
                     known_sigma2fs = NULL, taper = NULL, 
-                    simple_kriging_fixed = TRUE, ...) {
+                    simple_kriging_fixed = FALSE, ...) {
   
   ## Deprecation coercion
   tmp <- list(...)
